@@ -3,7 +3,6 @@ API module
 """
 
 from pathlib import Path, PurePath
-from typing import Optional
 from typing import Union
 
 from face_group.utils import (_copy_images_by_dict,
@@ -16,7 +15,8 @@ def process_images(
     output_dir: Union[str, PurePath],
     verbose: bool = False,
     model: str = "hog",
-    cpus: int = 1
+    cpus: int = 1,
+    tolerance: float = 0.6,
 ) -> None:
     """Про"""
     input_dir = Path(input_dir)
@@ -27,7 +27,7 @@ def process_images(
 
     np_face, np_path = _get_encodings_from_image_dir(input_dir, verbose, model, cpus)
 
-    face_dict = _sort_path_by_encodings(np_face, np_path)
+    face_dict = _sort_path_by_encodings(np_face, np_path, tolerance)
 
     _copy_images_by_dict(face_dict, input_dir, output_dir, verbose)
 
