@@ -2,7 +2,6 @@
 Command line module
 """
 import time
-from typing import Optional
 
 import click
 from click import Choice, Path
@@ -43,13 +42,27 @@ from face_group.api import process_images
     "cpus",
     default=1,
     type=int,
-    help='Number of CPU cores to use in parallel (can speed up processing lots of '
-         'images). -1 means "use all in system".',
+    help="Number of CPU cores to use in parallel (can speed up processing lots of "
+    'images). -1 means "use all in system".',
 )
-def group_faces(input_dir: str, output_dir: str, verbose: bool, model: str, cpus: int) \
-        -> None:
+@click.option(
+    "-t",
+    "--tolerance",
+    "tolerance",
+    default=0.6,
+    type=float,
+    help="How much distance between faces to consider it a match. Lower is more strict. 0.6 is typical best performance.",
+)
+def group_faces(
+    input_dir: str,
+    output_dir: str,
+    verbose: bool,
+    model: str,
+    cpus: int,
+    tolerance: float,
+) -> None:
     """It groups the faces of similar people"""
 
     start = time.time()
-    process_images(input_dir, output_dir, verbose, model, cpus)
+    process_images(input_dir, output_dir, verbose, model, cpus, tolerance)
     click.echo(f"Done in {time.time() - start}s")
